This function creates a lineup plot to assess the additivity of a predictor's effect. It uses a nonparametric bootstrap approach to generate null plots.
Usage
additivityLineup(
backfit_obj,
fitMethod,
realICE,
figs = 10,
colorvecfcn,
usecolorvecfcn_inreal = FALSE,
null_predictfcn,
...
)Arguments
- backfit_obj
An object of class
backfitter.- fitMethod
A function that accepts
Xandyand returns a fitted model.- realICE
The
iceobject for the real data.- figs
The total number of plots in the lineup (including the real one). Default is 10.
- colorvecfcn
Optional function to generate a color vector for the curves.
- usecolorvecfcn_inreal
If
TRUE, usecolorvecfcnfor the real plot.- null_predictfcn
Optional prediction function for the null models.
- ...
Additional arguments passed to
plot.ice.